@@ -3,11 +3,16 @@
 {-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE ScopedTypeVariables #-}
+{-# LANGUAGE BangPatterns #-}
 
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 
 module Network.HTTP.Client.Request
     ( parseUrl
+    , parseUrlThrow
+    , parseRequest
+    , parseRequest_
+    , defaultRequest
     , setUriRelative
     , getUri
     , setUri
@@ -20,6 +25,7 @@ module Network.HTTP.Client.Request
     , needsGunzip
     , requestBuilder
     , useDefaultTimeout
+    , setRequestIgnoreStatus
     , setQueryString
     , streamFile
     , observedStreamFile
@@ -27,7 +33,7 @@ module Network.HTTP.Client.Request
     ) where
 
 import Data.Int (Int64)
-import Data.Maybe (fromMaybe, isJust)
+import Data.Maybe (fromMaybe, isJust, isNothing)
 import Data.Monoid (mempty, mappend)
 import Data.String (IsString(..))
 import Data.Char (toLower)
@@ -66,26 +72,20 @@ import Data.IORef
 import System.IO (withBinaryFile, hTell, hFileSize, Handle, IOMode (ReadMode))
 import Control.Monad (liftM)
 
--- | Convert a URL into a 'Request'.
+-- | Deprecated synonym for 'parseUrlThrow'. You probably want
+-- 'parseRequest' or 'parseRequest_' instead.
 --
--- This defaults some of the values in 'Request', such as setting 'method' to
--- GET and 'requestHeaders' to @[]@.
---
--- Since this function uses 'MonadThrow', the return monad can be anything that is
--- an instance of 'MonadThrow', such as 'IO' or 'Maybe'.
---
--- You can place the request method at the beginning of the URL separated by a
--- space, e.g.:
---
--- @@@
--- parseUrl "POST http://httpbin.org/post"
--- @@@
---
--- Note that the request method must be provided as all capital letters.
---
--- Since 0.1.0
+-- @since 0.1.0
 parseUrl :: MonadThrow m => String -> m Request
-parseUrl s' =
+parseUrl = parseUrlThrow
+{-# DEPRECATED parseUrl "Please use parseUrlThrow, parseRequest, or parseRequest_ instead" #-}
+
+-- | Same as 'parseRequest', except will throw an 'HttpException' in
+-- the event of a non-2XX response.
+--
+-- @since 0.4.30
+parseUrlThrow :: MonadThrow m => String -> m Request
+parseUrlThrow s' =
     case parseURI (encode s) of
         Just uri -> liftM setMethod (setUri def uri)
         Nothing  -> throwM $ InvalidUrlException s "Invalid URL"
@@ -101,6 +101,37 @@ parseUrl s' =
             Nothing -> req
             Just m -> req { method = S8.pack m }
 
+
+-- | Convert a URL into a 'Request'.
+--
+-- This defaults some of the values in 'Request', such as setting 'method' to
+-- GET and 'requestHeaders' to @[]@.
+--
+-- Since this function uses 'MonadThrow', the return monad can be anything that is
+-- an instance of 'MonadThrow', such as 'IO' or 'Maybe'.
+--
+-- You can place the request method at the beginning of the URL separated by a
+-- space, e.g.:
+--
+-- @@@
+-- parseRequeset "POST http://httpbin.org/post"
+-- @@@
+--
+-- Note that the request method must be provided as all capital letters.
+--
+-- @since 0.4.30
+parseRequest :: MonadThrow m => String -> m Request
+parseRequest =
+    liftM noThrow . parseUrlThrow
+  where
+    noThrow req = req { checkStatus = \_ _ _ -> Nothing }
+
+-- | Same as 'parseRequest', but in the cases of a parse error
+-- generates an impure exception. Mostly useful for static strings which
+-- are known to be correctly formatted.
+parseRequest_ :: String -> Request
+parseRequest_ = either throw id . parseRequest
+
 -- | Add a 'URI' to the request. If it is absolute (includes a host name), add
 -- it as per 'setUri'; if it is relative, merge it with the existing request.
 setUriRelative :: MonadThrow m => Request -> URI -> m Request
@@ -218,6 +249,12 @@ instance Show Request where
 useDefaultTimeout :: Maybe Int
 useDefaultTimeout = Just (-3425)
 
+-- | A default request value
+--
+-- @since 0.4.30
+defaultRequest :: Request
+defaultRequest = def { checkStatus = \_ _ _ -> Nothing }
+
 instance Default Request where
     def = Request
         { host = "localhost"
@@ -279,7 +316,7 @@ browserDecompress = (/= "application/x-tar")
 -- | Add a Basic Auth header (with the specified user name and password) to the
 -- given Request. Ignore error handling:
 --
--- >  applyBasicAuth "user" "pass" $ fromJust $ parseUrl url
+-- >  applyBasicAuth "user" "pass" $ parseRequest_ url
 --
 -- Since 0.1.0
 applyBasicAuth :: S.ByteString -> S.ByteString -> Request -> Request
@@ -300,7 +337,7 @@ addProxy hst prt req =
 -- | Add a Proxy-Authorization header (with the specified username and
 -- password) to the given 'Request'. Ignore error handling:
 --
--- > applyBasicProxyAuth "user" "pass" <$> parseUrl "http://example.org"
+-- > applyBasicProxyAuth "user" "pass" <$> parseRequest "http://example.org"
 --
 -- Since 0.3.4
 
@@ -369,7 +406,7 @@ requestBuilder req Connection {..} = do
     toTriple (RequestBodyStream len stream) = do
         -- See https://github.com/snoyberg/http-client/issues/74 for usage
         -- of flush here.
-        let body = writeStream False stream
+        let body = writeStream (Just . fromIntegral $ len) stream
             -- Don't check for a bad send on the headers themselves.
             -- Ideally, we'd do the same thing for the other request body
             -- types, but it would also introduce a performance hit since
@@ -377,28 +414,32 @@ requestBuilder req Connection {..} = do
             now  = flushHeaders (Just len) >> checkBadSend body
         return (Just len, now, body)
     toTriple (RequestBodyStreamChunked stream) = do
-        let body = writeStream True stream
+        let body = writeStream Nothing stream
             now  = flushHeaders Nothing >> checkBadSend body
         return (Nothing, now, body)
     toTriple (RequestBodyIO mbody) = mbody >>= toTriple
 
-    writeStream isChunked withStream =
-        withStream loop
+    writeStream mlen withStream =
+        withStream (loop 0) 
       where
-        loop stream = do
+        loop !n stream = do
             bs <- stream
             if S.null bs
-                then when isChunked $ connectionWrite "0\r\n\r\n"
+                then case mlen of 
+                    -- If stream is chunked, no length argument
+                    Nothing -> connectionWrite "0\r\n\r\n"
+                    -- Not chunked - validate length argument
+                    Just len -> unless (len == n) $ throwIO $ WrongRequestBodyStreamSize (fromIntegral len) (fromIntegral n)
                 else do
                     connectionWrite $
-                        if isChunked
+                        if (isNothing mlen) -- Chunked
                             then S.concat
                                 [ S8.pack $ showHex (S.length bs) "\r\n"
                                 , bs
                                 , "\r\n"
                                 ]
                             else bs
-                    loop stream
+                    loop (n + (S.length bs)) stream
 
 
     hh
@@ -469,6 +510,13 @@ requestBuilder req Connection {..} = do
         <> fromByteString v
         <> fromByteString "\r\n"
 
+-- | Modify the request so that non-2XX status codes do not generate a runtime
+-- 'StatusCodeException'.
+--
+-- @since 0.4.29
+setRequestIgnoreStatus :: Request -> Request
+setRequestIgnoreStatus req = req { checkStatus = \_ _ _ -> Nothing }
+
 -- | Set the query string to the given key/value pairs.
 --
 -- Since 0.3.6
